==> xscorch_0.1.14.orig.tar.gz: xscorch-0.1.14/sgtk/simage-gtk.c <==
/* $Header: /fridge/cvs/xscorch/sgtk/simage-gtk.c,v 1.2 2001/04/07 19:44:17 justins Exp $ */
/*
   
   xscorch - simage-gtk.c     Copyright(c) 2001,2000 Justin David Smith
   justins(at)chaos2.org      http://chaos2.org/
    
   GTK interface to image drawing
    

   This program is free software; you can redistribute it and/or modify 
   it under the terms of the GNU General Public License as published by 
   the Free Software Foundation; either version 2 of the License, or 
   (at your option) any later version.

   This program is distributed in the hope that it will be useful, 
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/
#include <simage-gtk.h>



inline gint sc_pixmap_width_gtk(GdkPixmap *pix) {

   gint width;
   
   width = 0;
   gdk_window_get_size(pix, &width, NULL);
   return(width);

}

 
 
inline gint sc_pixmap_height_gtk(GdkPixmap *pix) {

   gint height;
   
   height = 0;
   gdk_window_get_size(pix, NULL, &height);
   return(height);

}



void sc_pixmap_copy_gtk(GdkPixmap *dest, GdkGC *gc, GdkPixmap *src, GdkBitmap *mask, int dx, int dy) {

   gdk_gc_set_clip_origin(gc, dx, dy);
   gdk_gc_set_clip_mask(gc, mask);
   gdk_draw_pixmap(dest, gc, src, 0, 0, dx, dy, sc_pixmap_width_gtk(src), sc_pixmap_height_gtk(src));
   gdk_gc_set_clip_mask(gc, NULL);
   
}

==> xscorch_0.2.0.orig.tar.gz: xscorch-0.2.0/sgtk/simage-gtk.c <==
/* $Header: /fridge/cvs/xscorch/sgtk/simage-gtk.c,v 1.5 2004/02/26 06:34:55 justins Exp $ */
/*
   
   xscorch - simage-gtk.c     Copyright(c) 2000-2003 Justin David Smith
   justins(at)chaos2.org      http://chaos2.org/
    
   GTK interface to image drawing
    

   This program is free software; you can redistribute it and/or modify 
   it under the terms of the GNU General Public License as published by 
   the Free Software Foundation, version 2 of the License ONLY. 

   This program is distributed in the hope that it will be useful, 
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/
#include <sgtk.h>
#include <simage-gtk.h>



inline gint sc_pixmap_width_gtk(GdkPixmap *pix) {

   gint width;
   
   width = 0;
   gdk_drawable_get_size(pix, &width, NULL);
   return(width);

}

 
 
inline gint sc_pixmap_height_gtk(GdkPixmap *pix) {

   gint height;
   
   height = 0;
   gdk_drawable_get_size(pix, NULL, &height);
   return(height);

}



void sc_pixmap_copy_gtk(GdkPixmap *dest, GdkGC *gc, GdkPixmap *src, GdkBitmap *mask, int dx, int dy) {

   gdk_gc_set_clip_origin(gc, dx, dy);
   gdk_gc_set_clip_mask(gc, mask);
   gdk_draw_drawable(dest, gc, src,
                     0, 0,
                     dx, dy,
                     sc_pixmap_width_gtk(src),
                     sc_pixmap_height_gtk(src));
   gdk_gc_set_clip_mask(gc, NULL);
   
}
